QYILITIX PROJECT
---------------------------


To use (package), simply do::
    
    >>> from qlytix_pack import (func's)
        or
    >>> import qlytix_pack
    
To install ::

    >>> pip install qlytix-package